function [eta2,se,lk]=fit_conditional_rev3(Y,X,eta)

%           [eta2,se,lk]=fit_conditional_rev(Y,X,eta) 
%
% Fit a quadratic exponential distribution for panel binary data through Conditional Maximum Likelihood.
% Y      : matrix of binary response variable of dimension r x c (r=units, c=times)
% X      : matrix of covariates of dimension k x r x c (k=number of covariates)
% eta    : vector of first guess of the regression parameters of dimension k
% eta2   : vector of estimated parameters of dimension k
% se     : vector of standard errors of dimension k
% lk     : log-likelihood value at convergence.
%

%Francesco Bartolucci, Valentina Nigro
%Date: 19/12/2006

% Load data 
ind = find(sum(Y(:,2:end),2)>0 & sum(Y(:,2:end),2)<size(Y,2)-1); 
disp('effective sample size');
disp(length(ind)/size(Y,1));
Y = Y(ind,:); X = X(:,ind,:);
[k,r,c] = size(X);  %c comprende y0
nc = size(X,1)+1;  %number of regression parameters
%Fisher-scoring
Pc = zeros(r,1);
it = 0; lk = 0; lko = 0;
sY = sum(Y(:,2:c),2);
d = zeros(r,1);
S = sq(c-1); sS = sum(S,2);
while abs(lk-lko)>10^-5 | it == 0,
    it = it+1; lko = lk;
    lk = 0; d1 = zeros(nc,1); D2 = zeros(nc);
    % numerator
    for i=1:r,
        tnum = [reshape(X(:,i,2:end),[k c-1 1])*Y(i,2:end)'; Y(i,2:end)*Y(i,1:end-1)'];
        num = exp(tnum'*eta);
        d1 = d1+tnum;
        % denominator
        indg = find(sS==sY(i)); lg = length(indg);
        g = [Y(i,1)*ones(lg,1) S(indg,:)]; pg = sum(g(:,1:end-1).*g(:,2:end),2);
        d1g = zeros(nc,1); D2g = zeros(nc); Vd1 = zeros(nc);
        Tden=g(:,2:end)*permute(X(:,i,2:end),[3,1,2]);
        Tden = [Tden pg];
        pt = exp(Tden*eta);
        den = sum(pt);
        d1g = Tden'*pt;
        D2g = Tden'*diagv(pt,Tden);
        % log-likelihood and derivatives
        lk = lk+log(num/den);
        d1 = d1-d1g/den;
        D2 = D2-(D2g*den-d1g*d1g')/den^2;
    end
    deta = -pinv(D2)*d1;
    mdeta = max(abs(deta));
    if mdeta>0.5,
        deta = deta/mdeta*0.5;
    end
    eta = eta+deta;
end
eta2=eta;
se = sqrt(diag(inv(-D2)));
disp('Conditional estimator');
disp([it lk lk-lko eta']);
