% Simulation from quadratic exponential model (case: regressors with temporal trend)

r0 = 500;    % number of observations, choose between 250,500,1000 
c0 = 4;      % number of time periods, choose between 4,8
nsim = 1000; % number of simulations
be2 = 1; 
ga = 0.5;    % parameter of state dependence, choose between 0.25, 0.5, 1, 2
etat = [ be2  ga]'; 
randn('state',0)
rand('state',0)
Eta = []; Se = [];Etai=[];Sei=[];Etam=[];Sem=[];
S = sq(c0-1);
lg = 2^(c0-1);
g1 = [ones(lg,1) S]; pg1 = sum(g1(:,1:end-1).*g1(:,2:end),2);
g0 = [zeros(lg,1) S]; pg0 = sum(g0(:,1:end-1).*g0(:,2:end),2);
%simulation
for si = 1:nsim,
% Set up covariates matrix
    X0=zeros(r0,c0);tr=zeros(r0,c0);
    X0(:,1) = randn(r0,1)*(1/sqrt(1-0.5^2));tr(:,1)=0.1;
    for j=2:c0,
        X0(:,j)=0.5*X0(:,j-1)+randn(r0,1);  %AR(1) process
        tr(:,j)=0.1*j;
    end
    tr=tr-mean(mean(tr))*ones(r0,c0);
    al=mean(X0*sqrt(1-0.5^2)*sqrt(pi^2/3),2);
    X0=(X0+tr)*sqrt(1-0.5^2)*sqrt(pi^2/3);  %normalization
    ZZ = zeros(length(etat)-1,r0,c0);
    for i=1:r0,
        for j=1:c0,
            ZZ(:,i,j) = X0(i,j);
        end
    end
    Y = zeros(r0,c0);
    for i = 1:r0,
        p2=exp(al(i)+be2*X0(i,1)); p2=p2/(1+p2);
        Y(i,1)=p2>rand;   %y0 logistico
        p = zeros(2^(c0-1),1);
        for is = 1:2^(c0-1),
            t2 = [ZZ(:,i,2)*S(is,1); Y(i,1)*S(is,1)]; 
            for j = 2:c0-1,
                if j==c0-1,
                    t2 = t2 + [ZZ(:,i,1+j)*S(is,j); S(is,j-1)*S(is,j)+0.5];
                else
                    t2 = t2 + [ZZ(:,i,1+j)*S(is,j); S(is,j-1)*S(is,j)];
                end     
            end      
            p(is) = exp(al(i)*sum(S(is,:))+t2'*etat);
        end
        p = p/sum(p);
        ind = find(rmult(1,p'));
        Y(i,2:end) = S(ind,:);
    end
    fprintf('Simulation------------------------ %3.0f  ',si);fprintf('\n');
    % Conditional estimate
    X = ZZ;
    eta0=zeros(length(etat)+2,1);
    Y1 = Y(:,1:c0); 
    X1 = zeros(3,r0,c0);
    X1(1,:,1:c0-1) = X(1,:,1:c0-1);
    X1(2,:,c0) = 1;
    X1(3,:,c0) = X(1,:,c0);
    [eta,se,lk]=fit_conditional_rev3(Y1,X1,eta0);
    Eta = [Eta; eta'];
    Se = [Se; se'];
end
